@@ -1,9 +1,9 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2019-2022 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2019-2023 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.79;
+package Object::Pad 0.800;
 
 use v5.14;
 use warnings;
@@ -107,8 +107,6 @@ silence every experimental warning, which may hide others unintentionally. For
 a more fine-grained approach you can instead use the import line for this
 module to only silence the module's warnings selectively:
 
-   use Object::Pad ':experimental(init_expr)';
-
    use Object::Pad ':experimental(mop)';
 
    use Object::Pad ':experimental(custom_field_attr)';
@@ -122,7 +120,7 @@ I<Since version 0.64.>
 Multiple experimental features can be enabled at once by giving multiple names
 in the parens, separated by spaces:
 
-   use Object::Pad ':experimental(init_expr mop)';
+   use Object::Pad ':experimental(mop adjust_params)';
 
 =head2 Automatic Construction
 
@@ -635,10 +633,8 @@ would be dangerous to allow access to it while in this state. However, the
 C<__CLASS__> keyword is available, so initialiser expressions can make use of
 class-based dispatch to invoke class-level methods to help provide values.
 
-This feature should be considered partly B<experimental> and may emit warnings
-to that effect. They can be silenced with
-
-   use Object::Pad ':experimental(init_expr)';
+Field initialier expressions were originally experimental, but I<since version
+0.800> no longer emit experimental warnings.
 
 I<Since version 0.76> expressions that are purely compiletime constants
 (either as single scalars or entire lists of constants) are no longer
@@ -667,15 +663,16 @@ they appear within are permitted.
 
    has $var { BLOCK }
 
-An older version of the L</field> keyword.
+A now-deprecated older version of the L</field> keyword.
 
 This generally behaves like C<field>, except that inline expressions are
 evaluated immediately, once, during class declaration time. These are I<not>
 stored to be evaluated for each constructor.
 
 Because of the one-shot immediate nature of these initialisation expressions
-(and a bunch of other reasons), the C<has> keyword is now discouraged for use.
-Use the C<field> keyword instead.
+(and a bunch of other reasons), the C<has> keyword is now discouraged for use
+and will emit compile-time warnings in the C<deprecated> category. Use the
+C<field> keyword instead.
 
 If you need to evaluate an expression exactly once during the class
 declaration and assign its now-constant value to every instace, store it in a
@@ -1012,31 +1009,65 @@ found useful.
 
 =head2 Implied Pragmata
 
+B<The following behaviour is likely to be removed in a later version of this
+module.>
+
 In order to encourage users to write clean, modern code, the body of the
-C<class> block acts as if the following pragmata are in effect:
+C<class> block currently acts as if the following pragmata are in effect:
 
    use strict;
    use warnings;
    no indirect ':fatal';  # or  no feature 'indirect' on perl 5.32 onwards
    use feature 'signatures';
 
-This list may be extended in subsequent versions to add further restrictions
-and should not be considered exhaustive.
+This behaviour was designed early around the original "line-0" version of the
+Perl 7 plan, which has subsequently been found to be a bad design and
+abandoned. That leaves this module in an unfortunate situation, because its
+behaviour here does not match the plans for core perl; where the
+recently-added C<class> keyword does none of this, although the C<method>
+keyword always behaves as if signatures were enabled anyway.
 
-Further additions will only be ones that remove "discouraged" or deprecated
-language features with the overall goal of enforcing a more clean modern style
-within the body. As long as you write code that is in a clean, modern style
-(and I fully accept that this wording is vague and subjective) you should not
-find any new restrictions to be majorly problematic. Either the code will
-continue to run unaffected, or you may have to make some small alterations to
-bring it into a conforming style.
+It is eventually planned that this behaviour will be removed from
+C<Object::Pad> entirely (except for enabling the C<signatures> feature). While
+that won't in itself break any existing code, it would mean that code which
+previously ran with the protection of C<strict> and C<warnings> would now not
+be. A satisfactory solution to this problem has not yet been found, but until
+then it is suggested that code using this module remembers to explicitly
+enable this set of pragmata before using the C<class> keyword.
+
+A handy way to do this is to use the C<use VERSION> syntax; v5.36 or later
+will already perform all of the pragmata listed above.
+
+   use v5.36;
+
+If you import this module with a module version number of C<0.800> or higher
+it will enable a warning if you forget to enable C<strict> and C<warnings>
+before using the C<class> or C<roll> keywords:
+
+   use Object::Pad 0.800;
+
+   class X { ... }
+
+Z<>
+
+   class keyword enabled 'use strict' but this will be removed in a later version at FILE line 3.
+   class keyword enabled 'use warnings' but this will be removed in a later version at FILE line 3.
 
 =head2 Yield True
 
+B<The following behaviour is likely to be removed in a later version of this
+module.>
+
 A C<class> statement or block will yield a true boolean value. This means that
 it can be used directly inside a F<.pm> file, avoiding the need to explicitly
 yield a true value from the end of it.
 
+As with the implied pragmata above, this behaviour has also been found to be a
+bad design and will likely be removed soon. For now it is suggested not to
+rely on it and instead either use the new C<module_true> feature already part
+of the C<use v5.38> pragma, or on older perls simply remember to put an
+explicit true value at the end of the file.
+
 =head1 SUBCLASSING CLASSIC PERL CLASSES
 
 There are a number of details specific to the case of deriving an
@@ -1169,6 +1200,19 @@ more visually distinct.
 
 =cut
 
+sub VERSION
+{
+   my $pkg = shift;
+   my ( $ver ) = @_;
+
+   $pkg->SUPER::VERSION( $ver );
+
+   $ver = version->parse( $ver );
+
+   # Only bother to store it if it's >= v0.800
+   $^H{"Object::Pad/imported-version"} = $ver->numify if $ver ge v0.800;
+}
+
 sub import
 {
    my $class = shift;
